@@ -10,11 +10,11 @@ Crypt::LE - Let's Encrypt API interfacing module.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -78,6 +78,9 @@ INVALID_DATA
 =item *
 DATA_MISMATCH 
 
+=item *
+ALREADY_DONE
+
 =item *
 ERROR
 
@@ -131,11 +134,11 @@ use constant ERROR                  => 500;
 use constant SUCCESS                => 200;
 use constant CREATED                => 201;
 use constant ACCEPTED               => 202;
-use constant ALREADY_REGISTERED     => 409;
+use constant ALREADY_DONE           => 409;
 
 use constant NID_subject_alt_name   => 85;
 
-our @EXPORT_OK = (qw<OK READ_ERROR LOAD_ERROR INVALID_DATA DATA_MISMATCH ERROR>);
+our @EXPORT_OK = (qw<OK READ_ERROR LOAD_ERROR INVALID_DATA DATA_MISMATCH ERROR ALREADY_DONE>);
 our %EXPORT_TAGS = ( errors => [ @EXPORT_OK ] );
 
 my $header = 'replay-nonce';
@@ -487,7 +490,7 @@ sub register {
     $req->{contact} = [ "mailto:$self->{email}" ] if $self->{email};
     my ($status, $content) = $self->_request($self->{directory}->{'new-reg'}, $req);
     $self->{directory}->{reg} = $self->{location} if $self->{location};
-    if ($status == ALREADY_REGISTERED) {
+    if ($status == ALREADY_DONE) {
         $self->{new_registration} = 0;
         $self->_debug("Key is already registered, reg path: $self->{directory}->{reg}.");
         ($status, $content) = $self->_request($self->{directory}->{'reg'}, { resource => 'reg' });
@@ -663,7 +666,7 @@ sub accept_challenge {
     $type||='http';
     my $handler = "handle_challenge_$type";
     return $self->_status(INVALID_DATA, "Valid callback has not been provided.") unless ($cb and ((ref $cb eq 'CODE') or ($mod_callback and $cb->can($handler))));
-	return $self->_status(INVALID_DATA, "Passed parameters are not pointing to a hash.") if ($params and (ref $params ne 'HASH'));
+    return $self->_status(INVALID_DATA, "Passed parameters are not pointing to a hash.") if ($params and (ref $params ne 'HASH'));
     my ($domains_accepted, @domains_failed);
     $self->{active_challenges} = undef;
     foreach my $domain (sort keys %{$self->{domains}}) {
@@ -803,17 +806,22 @@ sub request_issuer_certificate {
 
 Revokes a certificate.
 
-B<Returns>: OK | READ_ERROR | ERROR.
+B<Returns>: OK | READ_ERROR | ALREADY_DONE | ERROR.
 
 =cut
 
 sub revoke_certificate {
     my $self = shift;
-	my $file = shift;
-	my $crt = $self->_file($file);
+    my $file = shift;
+    my $crt = $self->_file($file);
     return $self->_status(READ_ERROR, "Could not read the certificate from '$file'.") unless $crt;
-	my ($status, $content) = $self->_request($self->{directory}->{'revoke-cert'}, { resource => 'revoke-cert', certificate => encode_base64url(Crypt::Format::pem2der($crt)) });
-    return ($status == SUCCESS) ? $self->_status(OK, "Certificate has been revoked.") : $self->_status(ERROR, $content);
+    my ($status, $content) = $self->_request($self->{directory}->{'revoke-cert'}, { resource => 'revoke-cert', certificate => encode_base64url(Crypt::Format::pem2der($crt)) });
+    if ($status == SUCCESS) {
+        return $self->_status(OK, "Certificate has been revoked.");
+    } elsif ($status == ALREADY_DONE) {
+        return $self->_status(ALREADY_DONE, "Certificate has been already revoked.");
+    }
+    return $self->_status(ERROR, $content);
 }
 
 #====================================================================================================
