@@ -9,7 +9,7 @@ use Crypt::LE ':errors';
 sub info { print shift, "\n" }
 sub bail { &info; exit 255 }
 
-my $VERSION = '0.06';
+my $VERSION = '0.07';
 
 my ($account_key, $csr, $csr_key, $domains, $challenge_path, $crt, $live, $generate_missing, $generate_only, 
     $handle_with, $handle_as, $handle_params, $complete_with, $complete_params, $revoke, $verified, $debug, $help);
@@ -54,9 +54,9 @@ Available parameters:
  path <absolute path>             - Path to local .well-known/acme-challenge/ to drop required challenge files into (optional).
  handle-with <Some::Module>       - Module name to handle challenges with (optional).
  handle-as <http|dns|tls|...>     - Type of challenge to request, by default 'http' (optional).
- handle-params <{json}>           - JSON with parameters to be passed to the challenge-handling module (optional).
+ handle-params <{json}|file>      - JSON (or name of the file containing it) with parameters to be passed to the challenge-handling module (optional).
  complete-with <Another::Module>  - Module name to handle process completion with (optional).
- complete-params <{json}>         - JSON with parameters to be passed to the completion-handling module (optional).
+ complete-params <{json}|file>    - JSON (or name of the file containing it) with parameters to be passed to the completion-handling module (optional).
  generate-missing                 - Generate missing files (key, csr and csr-key).
  generate-only                    - Generate a new key and/or CSR if they are missing and then exit.
  crt <file>                       - Name for the domain certificate file.
@@ -72,6 +72,7 @@ info "\nCrypt::LE client v$VERSION started.\n";
 
 bail $usage if $help;
 my ($handler, $complete_handler);
+binmode(STDOUT, ":utf8");
 
 unless ($account_key and (-r $account_key or $generate_missing)) {
     info "Incorrect parameters - need an account key loaded or generated.";
@@ -106,14 +107,7 @@ if ($revoke) {
         $handler = new $handle_with;
         my $method = 'handle_challenge_' . $handle_as;
         bail "Module to handle challenges does not seem to support the challenge type of '$handle_as'." unless $handler->can($method);
-        if ($handle_params) {
-	    my $j = JSON->new->canonical()->allow_nonref();
-            eval {
-	        $handle_params = $j->decode($handle_params);
-            };
-            bail "Could not decode parameters for the challenge-handling module: $@" if $@;
-            bail "Please make sure that your 'handle-params' JSON document has {} around it." unless (ref $handle_params eq 'HASH');
-        }
+        $handle_params = _load_params($handle_params, 'handle-params');
     } else {
         undef $handle_params;
     }
@@ -123,14 +117,7 @@ if ($revoke) {
         bail "Cannot use the module to complete processing with." if $@;
         $complete_handler = new $complete_with;
         bail "Module to complete processing with does not seem to support the required 'complete' method." unless $complete_handler->can('complete');
-        if ($complete_params) {
-            my $j = JSON->new->canonical()->allow_nonref();
-            eval {
-                $complete_params = $j->decode($complete_params);
-            };
-            bail "Could not decode parameters for the completion module: $@" if $@;
-            bail "Please make sure that your 'complete-params' JSON document has {} around it." unless (ref $complete_params eq 'HASH');
-        }
+        $complete_params = _load_params($complete_params, 'complete-params');
     } else {
         undef $complete_params;
     }
@@ -151,8 +138,14 @@ if (-r $account_key) {
 }
 
 if ($revoke) {
-    bail $le->error_details if $le->revoke_certificate($crt);
-    info "Certificate has been revoked.";
+    my $rv = $le->revoke_certificate($crt);
+    if ($rv == OK) {
+        info "Certificate has been revoked.";
+    } elsif ($rv == ALREADY_DONE) {
+        info "Certificate has been ALREADY revoked.";
+    } else {
+        bail "Problem with revoking certificate: " . $le->error_details;
+    }
     exit 0;
 }
 
@@ -205,6 +198,34 @@ if ($complete_handler) {
 
 info "The job is done, enjoy your certificate! For feedback and bug reports contact me at [ https://do-know.com ]";
 
+sub _load_params {
+    my ($src, $type) = @_;
+    return undef unless $src;
+    # To avoid adding more and more parameters, treat this as JSON if any of {}[] 
+    # are present or as a file otherwise.
+    if ($src!~/[\{\[\}\]]/) {
+        $src = _read($src);
+        bail "Could not read the file with '$type'." unless $src;
+    }
+    my $j = JSON->new->canonical()->allow_nonref();
+    eval {
+        $src = $j->decode($src);
+    };
+    bail "Could not decode '$type'. Please make sure you are providing a valid JSON document and {} are in place." . ($debug ? $@ : '') if ($@ or (ref $src ne 'HASH'));
+    return $src;
+}
+
+sub _read {
+    my $file = shift;
+    return unless (-e $file and -r _);
+    my $fh = IO::File->new();
+    $fh->open($file, '<:encoding(UTF-8)') or return;
+    local $/;
+    my $src = <$fh>;
+    $fh->close;
+    return $src;
+}
+
 sub _write {
     my ($file, $content) = @_;
     return 1 unless ($file and $content);
